=======
Credits
=======

.. _kiwnix: https://github.com/Dmitri-Sintsov/django-jinja-knockout/commits?author=kiwnix
.. _Melvyn Sopacua: https://github.com/Dmitri-Sintsov/django-jinja-knockout/commits?author=melvyn-sopacua

Development Lead
----------------

* Dmitriy Sintsov <questpc256@gmail.com>

Contributors
------------

* `Melvyn Sopacua`_: Compatibility to 1.10+ new-style middleware; Dutch localization.
* `kiwnix`_: Middleware import fixes;

Localization:

* Chinese: ``goldmonkey``
* Dutch: `Melvyn Sopacua`_
* Polish: ``pawelkoston``
* Spanish: ``Julio Cesar Cabrera Cabrera``, `kiwnix`_
